/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(Cos);
ADDSYMBOL(Degrees);
ADDSYMBOL(Sin);
ADDSYMBOL(Tan);
ADDSYMBOL(a);
ADDSYMBOL(aCos);
ADDSYMBOL(aSin);
ADDSYMBOL(aTan);
ADDSYMBOL(abs);
ADDSYMBOL(abs2);
ADDSYMBOL(angle);
ADDSYMBOL(b);
ADDSYMBOL(bezier);
ADDSYMBOL(bezierP);
ADDSYMBOL(bezierPP);
ADDSYMBOL(bezierPPP);
ADDSYMBOL(c);
ADDSYMBOL(conj);
ADDSYMBOL(cos);
ADDSYMBOL(cross);
ADDSYMBOL(d);
ADDSYMBOL(deg);
ADDSYMBOL(degrees);
ADDSYMBOL(dir);
ADDSYMBOL(dot);
ADDSYMBOL(exp);
ADDSYMBOL(expi);
ADDSYMBOL(gamma);
ADDSYMBOL(length);
ADDSYMBOL(log);
ADDSYMBOL(radians);
ADDSYMBOL(realmult);
ADDSYMBOL(sin);
ADDSYMBOL(sqrt);
ADDSYMBOL(t);
ADDSYMBOL(unit);
ADDSYMBOL(w);
ADDSYMBOL(warn);
ADDSYMBOL(x);
ADDSYMBOL(xpart);
ADDSYMBOL(ypart);
ADDSYMBOL(z);
