/***** Autogenerated from runstring.in; changes will be overwritten *****/

#pragma once
namespace run {
void emptyString(vm::stack *);
void stringHashHelper(vm::stack *);
void stringHash(vm::stack *);
}

