/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(_begingroup3);
ADDSYMBOL(_draw);
ADDSYMBOL(_image);
ADDSYMBOL(_labelpath);
ADDSYMBOL(_shipout);
ADDSYMBOL(a);
ADDSYMBOL(add);
ADDSYMBOL(angle);
ADDSYMBOL(antialias);
ADDSYMBOL(axialshade);
ADDSYMBOL(b);
ADDSYMBOL(background);
ADDSYMBOL(beginTransform);
ADDSYMBOL(beginclip);
ADDSYMBOL(begingroup);
ADDSYMBOL(c);
ADDSYMBOL(center);
ADDSYMBOL(ci);
ADDSYMBOL(clip);
ADDSYMBOL(closed);
ADDSYMBOL(color);
ADDSYMBOL(colors);
ADDSYMBOL(compression);
ADDSYMBOL(copy);
ADDSYMBOL(core);
ADDSYMBOL(data);
ADDSYMBOL(deconstruct);
ADDSYMBOL(deletepreamble);
ADDSYMBOL(dest);
ADDSYMBOL(diffuse);
ADDSYMBOL(digits);
ADDSYMBOL(dobreak);
ADDSYMBOL(draw);
ADDSYMBOL(drawCylinder);
ADDSYMBOL(drawDisk);
ADDSYMBOL(drawSphere);
ADDSYMBOL(drawTube);
ADDSYMBOL(drawbeziertriangle);
ADDSYMBOL(drawpixel);
ADDSYMBOL(duration);
ADDSYMBOL(edges);
ADDSYMBOL(empty);
ADDSYMBOL(endTransform);
ADDSYMBOL(endclip);
ADDSYMBOL(endgroup);
ADDSYMBOL(endgroup3);
ADDSYMBOL(erase);
ADDSYMBOL(extenda);
ADDSYMBOL(extendb);
ADDSYMBOL(f);
ADDSYMBOL(fill);
ADDSYMBOL(fillrule);
ADDSYMBOL(final);
ADDSYMBOL(format);
ADDSYMBOL(fresnel0);
ADDSYMBOL(functionshade);
ADDSYMBOL(g);
ADDSYMBOL(geometry);
ADDSYMBOL(gouraudshade);
ADDSYMBOL(granularity);
ADDSYMBOL(grestore);
ADDSYMBOL(gsave);
ADDSYMBOL(half);
ADDSYMBOL(height);
ADDSYMBOL(initial);
ADDSYMBOL(interaction);
ADDSYMBOL(is3D);
ADDSYMBOL(javascript);
ADDSYMBOL(justify);
ADDSYMBOL(key);
ADDSYMBOL(knot);
ADDSYMBOL(latex);
ADDSYMBOL(latticeshade);
ADDSYMBOL(layer);
ADDSYMBOL(lights);
ADDSYMBOL(m);
ADDSYMBOL(margin);
ADDSYMBOL(max);
ADDSYMBOL(max3);
ADDSYMBOL(maxratio);
ADDSYMBOL(metallic);
ADDSYMBOL(min);
ADDSYMBOL(min3);
ADDSYMBOL(minratio);
ADDSYMBOL(n);
ADDSYMBOL(name);
ADDSYMBOL(nativeformat);
ADDSYMBOL(newpage);
ADDSYMBOL(ni);
ADDSYMBOL(nobreak);
ADDSYMBOL(offset);
ADDSYMBOL(opacity);
ADDSYMBOL(p);
ADDSYMBOL(palette);
ADDSYMBOL(pdf);
ADDSYMBOL(pena);
ADDSYMBOL(penb);
ADDSYMBOL(postscript);
ADDSYMBOL(preamble);
ADDSYMBOL(prefix);
ADDSYMBOL(prepend);
ADDSYMBOL(primitive);
ADDSYMBOL(ra);
ADDSYMBOL(radialshade);
ADDSYMBOL(rb);
ADDSYMBOL(s);
ADDSYMBOL(shader);
ADDSYMBOL(shift);
ADDSYMBOL(shininess);
ADDSYMBOL(shipout3);
ADDSYMBOL(size);
ADDSYMBOL(size3);
ADDSYMBOL(specular);
ADDSYMBOL(src);
ADDSYMBOL(straight);
ADDSYMBOL(stroke);
ADDSYMBOL(t);
ADDSYMBOL(tensorshade);
ADDSYMBOL(tessellate);
ADDSYMBOL(tex);
ADDSYMBOL(texpreamble);
ADDSYMBOL(texreset);
ADDSYMBOL(tup);
ADDSYMBOL(type);
ADDSYMBOL(uknot);
ADDSYMBOL(v);
ADDSYMBOL(vi);
ADDSYMBOL(view);
ADDSYMBOL(vknot);
ADDSYMBOL(wait);
ADDSYMBOL(weights);
ADDSYMBOL(width);
ADDSYMBOL(xmap);
ADDSYMBOL(z);
ADDSYMBOL(zoom);
